==> sdd.mercadopago2-0.2.1-sources.jar: ar/com/sdd/mercadopago/entity/customer/card/Identification.java <==
package ar.com.sdd.mercadopago.entity.customer.card;

/**
 * Mercado Pago SDK
 * Card Cardholder Identification class
 *
 * Created by Eduardo Paoletta on 12/15/16.
 */
public class Identification {

    private Long number = null;
    private String subtype = null;
    private String type = null;


    public Long getNumber() {
        return number;
    }

    public Identification setNumber(Long number) {
        this.number = number;
        return this;
    }

    public String getSubtype() {
        return subtype;
    }

    public Identification setSubtype(String subtype) {
        this.subtype = subtype;
        return this;
    }

    public String getType() {
        return type;
    }

    public Identification setType(String type) {
        this.type = type;
        return this;
    }

    @Override
    public String toString() {
        return "Identification ["
                + ((number != null) ? "number=" + number + ", " : "")
                + ((subtype != null) ? "subtype=" + subtype + ", " : "")
                + ((type != null) ? "type=" + type : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Identification that = (Identification) o;

        if (number != null ? !number.equals(that.number) : that.number != null) return false;
        if (subtype != null ? !subtype.equals(that.subtype) : that.subtype != null) return false;
        return type != null ? type.equals(that.type) : that.type == null;
    }

    @Override
    public int hashCode() {
        int result = number != null ? number.hashCode() : 0;
        result = 31 * result + (subtype != null ? subtype.hashCode() : 0);
        result = 31 * result + (type != null ? type.hashCode() : 0);
        return result;
    }
}

==> sdd.mercadopago2-0.2.5-sources.jar: ar/com/sdd/mercadopago/entity/customer/card/Identification.java <==
package ar.com.sdd.mercadopago.entity.customer.card;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.PropertyNamingStrategy;
import com.fasterxml.jackson.databind.annotation.JsonNaming;

/**
 * Mercado Pago SDK
 * Card Cardholder Identification class
 *
 * Created by Eduardo Paoletta on 12/15/16.
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonNaming(PropertyNamingStrategy.SnakeCaseStrategy.class)
public class Identification {

    private Long number = null;
    private String subtype = null;
    private String type = null;


    public Long getNumber() {
        return number;
    }

    public Identification setNumber(Long number) {
        this.number = number;
        return this;
    }

    public String getSubtype() {
        return subtype;
    }

    public Identification setSubtype(String subtype) {
        this.subtype = subtype;
        return this;
    }

    public String getType() {
        return type;
    }

    public Identification setType(String type) {
        this.type = type;
        return this;
    }

    @Override
    public String toString() {
        return "Identification ["
                + ((number != null) ? "number=" + number + ", " : "")
                + ((subtype != null) ? "subtype=" + subtype + ", " : "")
                + ((type != null) ? "type=" + type : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Identification that = (Identification) o;

        if (number != null ? !number.equals(that.number) : that.number != null) return false;
        if (subtype != null ? !subtype.equals(that.subtype) : that.subtype != null) return false;
        return type != null ? type.equals(that.type) : that.type == null;
    }

    @Override
    public int hashCode() {
        int result = number != null ? number.hashCode() : 0;
        result = 31 * result + (subtype != null ? subtype.hashCode() : 0);
        result = 31 * result + (type != null ? type.hashCode() : 0);
        return result;
    }
}
